A complete OpenID Connect implementation
========================================

.. image:: https://api.travis-ci.org/rohe/pyoidc.png?branch=master
    :target: https://travis-ci.org/rohe/pyoidc

.. image:: https://img.shields.io/pypi/pyversions/oic.svg
    :target: https://pypi.python.org/pypi/oic

.. image:: https://img.shields.io/pypi/v/oic.svg
    :target: https://pypi.python.org/pypi/oic

.. image:: https://img.shields.io/pypi/dm/oic.svg
    :target: https://pypi.python.org/pypi/oic

.. image:: https://landscape.io/github/rohe/pyoidc/master/landscape.svg?style=flat
    :target: https://landscape.io/github/rohe/pyoidc/master

This a fairly complete implementation of OpenID Connect as specified in the
`OpenID Connect Core specification`_. And as a side effect a complete
implementation of OAuth2.0 too. Please see `the documentation`_ to get started.

.. _OpenID Connect Core specification: http://openid.net/specs/openid-connect-core-1_0.html.
.. _the documentation: http://pyoidc.readthedocs.io/en/latest/index.html

Cudos to Vladislav Mladenov and Christian Mainka both at
Horst Görtz Institute for IT-Security, Ruhr-University Bochum, Germany
for helping me making the implementation more secure.

If you're interested in helping maintain and improve this package, we're
looking for you!

Please contact one of the current maintainers, `@lwm`_ or `@rohe`_.

.. _@lwm: https://github.com/lwm/
.. _@rohe: https://github.com/rohe/
